Calculates the Estimate to Complete (ETC), which is the expected cost to finish the remaining work.
References
Damnjanovic, Ivan, and Kenneth Reinschmidt. Data analytics for engineering and construction project risk management. No. 172534. Cham, Switzerland: Springer, 2020.
Examples
bac <- 100000
ev <- 35000
cpi <- 0.83
# ETC assuming remaining work at planned rate
etc <- etc(bac, ev)
cat("ETC (planned rate):", etc, "\n")
#> ETC (planned rate): 65000
# ETC assuming remaining work at current CPI
etc <- etc(bac, ev, cpi)
cat("ETC (current CPI):", round(etc, 2), "\n")
#> ETC (current CPI): 78313.25