Skip to contents

Calculates the Earned Value (EV) of work completed based on the Budget at Completion (BAC) and the actual work completion percentage.

Usage

ev(bac, actual_per_complete)

Arguments

bac

Budget at Completion (BAC) (total planned budget).

actual_per_complete

Actual work completion percentage.

Value

The function returns the Earned Value (EV) of work completed.

References

Damnjanovic, Ivan, and Kenneth Reinschmidt. Data analytics for engineering and construction project risk management. No. 172534. Cham, Switzerland: Springer, 2020.

See also

pv, ac, sv, cv, spi, cpi, eac

Examples

# Set the BAC and actual % complete for a toy project.
bac <- 100000
actual_per_complete <- 0.35

# Calculate the EV and print the results.
ev <- ev(bac, actual_per_complete)
cat("Earned Value (EV):", ev, "\n")
#> Earned Value (EV): 35000