Calculates the Variance at Completion (VAC), which is the difference between the budget and the expected final cost. Positive VAC indicates under budget, negative indicates over budget.
References
Damnjanovic, Ivan, and Kenneth Reinschmidt. Data analytics for engineering and construction project risk management. No. 172534. Cham, Switzerland: Springer, 2020.
Examples
bac <- 100000
eac <- 120482 # From EAC calculation
vac <- vac(bac, eac)
cat("Variance at Completion (VAC):", round(vac, 2), "\n")
#> Variance at Completion (VAC): -20482
cat("Project is expected to be", abs(round(vac, 2)), ifelse(vac < 0, "over", "under"), "budget\n")
#> Project is expected to be 20482 over budget